@@ -5,12 +5,10 @@ use strict;
 use Rose::HTML::Util();
 use Rose::HTML::Text;
 
-use Rose::HTML::Form::Field::OnOff::Selectable;
-use Rose::HTML::Object::WithWrapAroundChildren;
-our @ISA = qw(Rose::HTML::Object::WithWrapAroundChildren
-              Rose::HTML::Form::Field::OnOff::Selectable);
+use base qw(Rose::HTML::Object::WithWrapAroundChildren
+            Rose::HTML::Form::Field::OnOff::Selectable);
 
-our $VERSION = '0.554';
+our $VERSION = '0.606';
 
 __PACKAGE__->add_valid_html_attrs
 (
@@ -216,4 +214,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 LICENSE
 
-Copyright (c) 2009 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2010 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
